@@ -19,13 +19,18 @@ import re
 from typing import Dict, Sequence, Tuple, Type, Union
 import pkg_resources
 
-import google.api_core.client_options as ClientOptions  # type: ignore
-from google.api_core import exceptions as core_exceptions  # type: ignore
-from google.api_core import gapic_v1  # type: ignore
-from google.api_core import retry as retries  # type: ignore
+from google.api_core.client_options import ClientOptions
+from google.api_core import exceptions as core_exceptions
+from google.api_core import gapic_v1
+from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+try:
+    OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
+except AttributeError:  # pragma: NO COVER
+    OptionalRetry = Union[retries.Retry, object]  # type: ignore
+
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
 from google.cloud.automl_v1.services.auto_ml import pagers
@@ -68,7 +73,7 @@ class AutoMlAsyncClient:
     Currently the only supported ``location_id`` is "us-central1".
 
     On any input that is documented to expect a string parameter in
-    snake_case or kebab-case, either of those cases is accepted.
+    snake_case or dash-case, either of those cases is accepted.
     """
 
     _client: AutoMlClient
@@ -194,18 +199,18 @@ class AutoMlAsyncClient:
 
     async def create_dataset(
         self,
-        request: service.CreateDatasetRequest = None,
+        request: Union[service.CreateDatasetRequest, dict] = None,
         *,
         parent: str = None,
         dataset: gca_dataset.Dataset = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Creates a dataset.
 
         Args:
-            request (:class:`google.cloud.automl_v1.types.CreateDatasetRequest`):
+            request (Union[google.cloud.automl_v1.types.CreateDatasetRequest, dict]):
                 The request object. Request message for
                 [AutoMl.CreateDataset][google.cloud.automl.v1.AutoMl.CreateDataset].
             parent (:class:`str`):
@@ -283,17 +288,17 @@ class AutoMlAsyncClient:
 
     async def get_dataset(
         self,
-        request: service.GetDatasetRequest = None,
+        request: Union[service.GetDatasetRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> dataset.Dataset:
         r"""Gets a dataset.
 
         Args:
-            request (:class:`google.cloud.automl_v1.types.GetDatasetRequest`):
+            request (Union[google.cloud.automl_v1.types.GetDatasetRequest, dict]):
                 The request object. Request message for
                 [AutoMl.GetDataset][google.cloud.automl.v1.AutoMl.GetDataset].
             name (:class:`str`):
@@ -366,17 +371,17 @@ class AutoMlAsyncClient:
 
     async def list_datasets(
         self,
-        request: service.ListDatasetsRequest = None,
+        request: Union[service.ListDatasetsRequest, dict] = None,
         *,
         parent: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListDatasetsAsyncPager:
         r"""Lists datasets in a project.
 
         Args:
-            request (:class:`google.cloud.automl_v1.types.ListDatasetsRequest`):
+            request (Union[google.cloud.automl_v1.types.ListDatasetsRequest, dict]):
                 The request object. Request message for
                 [AutoMl.ListDatasets][google.cloud.automl.v1.AutoMl.ListDatasets].
             parent (:class:`str`):
@@ -456,18 +461,18 @@ class AutoMlAsyncClient:
 
     async def update_dataset(
         self,
-        request: service.UpdateDatasetRequest = None,
+        request: Union[service.UpdateDatasetRequest, dict] = None,
         *,
         dataset: gca_dataset.Dataset = None,
         update_mask: field_mask_pb2.FieldMask = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> gca_dataset.Dataset:
         r"""Updates a dataset.
 
         Args:
-            request (:class:`google.cloud.automl_v1.types.UpdateDatasetRequest`):
+            request (Union[google.cloud.automl_v1.types.UpdateDatasetRequest, dict]):
                 The request object. Request message for
                 [AutoMl.UpdateDataset][google.cloud.automl.v1.AutoMl.UpdateDataset]
             dataset (:class:`google.cloud.automl_v1.types.Dataset`):
@@ -541,10 +546,10 @@ class AutoMlAsyncClient:
 
     async def delete_dataset(
         self,
-        request: service.DeleteDatasetRequest = None,
+        request: Union[service.DeleteDatasetRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
@@ -555,7 +560,7 @@ class AutoMlAsyncClient:
         [metadata][google.longrunning.Operation.metadata] field.
 
         Args:
-            request (:class:`google.cloud.automl_v1.types.DeleteDatasetRequest`):
+            request (Union[google.cloud.automl_v1.types.DeleteDatasetRequest, dict]):
                 The request object. Request message for
                 [AutoMl.DeleteDataset][google.cloud.automl.v1.AutoMl.DeleteDataset].
             name (:class:`str`):
@@ -647,11 +652,11 @@ class AutoMlAsyncClient:
 
     async def import_data(
         self,
-        request: service.ImportDataRequest = None,
+        request: Union[service.ImportDataRequest, dict] = None,
         *,
         name: str = None,
         input_config: io.InputConfig = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
@@ -667,7 +672,7 @@ class AutoMlAsyncClient:
            field when it completes.
 
         Args:
-            request (:class:`google.cloud.automl_v1.types.ImportDataRequest`):
+            request (Union[google.cloud.automl_v1.types.ImportDataRequest, dict]):
                 The request object. Request message for
                 [AutoMl.ImportData][google.cloud.automl.v1.AutoMl.ImportData].
             name (:class:`str`):
@@ -760,11 +765,11 @@ class AutoMlAsyncClient:
 
     async def export_data(
         self,
-        request: service.ExportDataRequest = None,
+        request: Union[service.ExportDataRequest, dict] = None,
         *,
         name: str = None,
         output_config: io.OutputConfig = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
@@ -774,7 +779,7 @@ class AutoMlAsyncClient:
         completes.
 
         Args:
-            request (:class:`google.cloud.automl_v1.types.ExportDataRequest`):
+            request (Union[google.cloud.automl_v1.types.ExportDataRequest, dict]):
                 The request object. Request message for
                 [AutoMl.ExportData][google.cloud.automl.v1.AutoMl.ExportData].
             name (:class:`str`):
@@ -865,17 +870,17 @@ class AutoMlAsyncClient:
 
     async def get_annotation_spec(
         self,
-        request: service.GetAnnotationSpecRequest = None,
+        request: Union[service.GetAnnotationSpecRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> annotation_spec.AnnotationSpec:
         r"""Gets an annotation spec.
 
         Args:
-            request (:class:`google.cloud.automl_v1.types.GetAnnotationSpecRequest`):
+            request (Union[google.cloud.automl_v1.types.GetAnnotationSpecRequest, dict]):
                 The request object. Request message for
                 [AutoMl.GetAnnotationSpec][google.cloud.automl.v1.AutoMl.GetAnnotationSpec].
             name (:class:`str`):
@@ -944,11 +949,11 @@ class AutoMlAsyncClient:
 
     async def create_model(
         self,
-        request: service.CreateModelRequest = None,
+        request: Union[service.CreateModelRequest, dict] = None,
         *,
         parent: str = None,
         model: gca_model.Model = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
@@ -959,7 +964,7 @@ class AutoMlAsyncClient:
         each annotation spec.
 
         Args:
-            request (:class:`google.cloud.automl_v1.types.CreateModelRequest`):
+            request (Union[google.cloud.automl_v1.types.CreateModelRequest, dict]):
                 The request object. Request message for
                 [AutoMl.CreateModel][google.cloud.automl.v1.AutoMl.CreateModel].
             parent (:class:`str`):
@@ -1039,17 +1044,17 @@ class AutoMlAsyncClient:
 
     async def get_model(
         self,
-        request: service.GetModelRequest = None,
+        request: Union[service.GetModelRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> model.Model:
         r"""Gets a model.
 
         Args:
-            request (:class:`google.cloud.automl_v1.types.GetModelRequest`):
+            request (Union[google.cloud.automl_v1.types.GetModelRequest, dict]):
                 The request object. Request message for
                 [AutoMl.GetModel][google.cloud.automl.v1.AutoMl.GetModel].
             name (:class:`str`):
@@ -1118,17 +1123,17 @@ class AutoMlAsyncClient:
 
     async def list_models(
         self,
-        request: service.ListModelsRequest = None,
+        request: Union[service.ListModelsRequest, dict] = None,
         *,
         parent: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListModelsAsyncPager:
         r"""Lists models.
 
         Args:
-            request (:class:`google.cloud.automl_v1.types.ListModelsRequest`):
+            request (Union[google.cloud.automl_v1.types.ListModelsRequest, dict]):
                 The request object. Request message for
                 [AutoMl.ListModels][google.cloud.automl.v1.AutoMl.ListModels].
             parent (:class:`str`):
@@ -1208,10 +1213,10 @@ class AutoMlAsyncClient:
 
     async def delete_model(
         self,
-        request: service.DeleteModelRequest = None,
+        request: Union[service.DeleteModelRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
@@ -1221,7 +1226,7 @@ class AutoMlAsyncClient:
         [metadata][google.longrunning.Operation.metadata] field.
 
         Args:
-            request (:class:`google.cloud.automl_v1.types.DeleteModelRequest`):
+            request (Union[google.cloud.automl_v1.types.DeleteModelRequest, dict]):
                 The request object. Request message for
                 [AutoMl.DeleteModel][google.cloud.automl.v1.AutoMl.DeleteModel].
             name (:class:`str`):
@@ -1313,18 +1318,18 @@ class AutoMlAsyncClient:
 
     async def update_model(
         self,
-        request: service.UpdateModelRequest = None,
+        request: Union[service.UpdateModelRequest, dict] = None,
         *,
         model: gca_model.Model = None,
         update_mask: field_mask_pb2.FieldMask = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> gca_model.Model:
         r"""Updates a model.
 
         Args:
-            request (:class:`google.cloud.automl_v1.types.UpdateModelRequest`):
+            request (Union[google.cloud.automl_v1.types.UpdateModelRequest, dict]):
                 The request object. Request message for
                 [AutoMl.UpdateModel][google.cloud.automl.v1.AutoMl.UpdateModel]
             model (:class:`google.cloud.automl_v1.types.Model`):
@@ -1396,17 +1401,16 @@ class AutoMlAsyncClient:
 
     async def deploy_model(
         self,
-        request: service.DeployModelRequest = None,
+        request: Union[service.DeployModelRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Deploys a model. If a model is already deployed, deploying it
         with the same parameters has no effect. Deploying with different
         parametrs (as e.g. changing
-
         [node_number][google.cloud.automl.v1p1beta.ImageObjectDetectionModelDeploymentMetadata.node_number])
         will reset the deployment state without pausing the model's
         availability.
@@ -1420,7 +1424,7 @@ class AutoMlAsyncClient:
         completes.
 
         Args:
-            request (:class:`google.cloud.automl_v1.types.DeployModelRequest`):
+            request (Union[google.cloud.automl_v1.types.DeployModelRequest, dict]):
                 The request object. Request message for
                 [AutoMl.DeployModel][google.cloud.automl.v1.AutoMl.DeployModel].
             name (:class:`str`):
@@ -1502,10 +1506,10 @@ class AutoMlAsyncClient:
 
     async def undeploy_model(
         self,
-        request: service.UndeployModelRequest = None,
+        request: Union[service.UndeployModelRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
@@ -1520,7 +1524,7 @@ class AutoMlAsyncClient:
         completes.
 
         Args:
-            request (:class:`google.cloud.automl_v1.types.UndeployModelRequest`):
+            request (Union[google.cloud.automl_v1.types.UndeployModelRequest, dict]):
                 The request object. Request message for
                 [AutoMl.UndeployModel][google.cloud.automl.v1.AutoMl.UndeployModel].
             name (:class:`str`):
@@ -1602,11 +1606,11 @@ class AutoMlAsyncClient:
 
     async def export_model(
         self,
-        request: service.ExportModelRequest = None,
+        request: Union[service.ExportModelRequest, dict] = None,
         *,
         name: str = None,
         output_config: io.ModelExportOutputConfig = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
@@ -1620,7 +1624,7 @@ class AutoMlAsyncClient:
         completes.
 
         Args:
-            request (:class:`google.cloud.automl_v1.types.ExportModelRequest`):
+            request (Union[google.cloud.automl_v1.types.ExportModelRequest, dict]):
                 The request object. Request message for
                 [AutoMl.ExportModel][google.cloud.automl.v1.AutoMl.ExportModel].
                 Models need to be enabled for exporting, otherwise an
@@ -1713,17 +1717,17 @@ class AutoMlAsyncClient:
 
     async def get_model_evaluation(
         self,
-        request: service.GetModelEvaluationRequest = None,
+        request: Union[service.GetModelEvaluationRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> model_evaluation.ModelEvaluation:
         r"""Gets a model evaluation.
 
         Args:
-            request (:class:`google.cloud.automl_v1.types.GetModelEvaluationRequest`):
+            request (Union[google.cloud.automl_v1.types.GetModelEvaluationRequest, dict]):
                 The request object. Request message for
                 [AutoMl.GetModelEvaluation][google.cloud.automl.v1.AutoMl.GetModelEvaluation].
             name (:class:`str`):
@@ -1792,18 +1796,18 @@ class AutoMlAsyncClient:
 
     async def list_model_evaluations(
         self,
-        request: service.ListModelEvaluationsRequest = None,
+        request: Union[service.ListModelEvaluationsRequest, dict] = None,
         *,
         parent: str = None,
         filter: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListModelEvaluationsAsyncPager:
         r"""Lists model evaluations.
 
         Args:
-            request (:class:`google.cloud.automl_v1.types.ListModelEvaluationsRequest`):
+            request (Union[google.cloud.automl_v1.types.ListModelEvaluationsRequest, dict]):
                 The request object. Request message for
                 [AutoMl.ListModelEvaluations][google.cloud.automl.v1.AutoMl.ListModelEvaluations].
             parent (:class:`str`):
