@@ -16,9 +16,9 @@
 import warnings
 from typing import Callable, Dict, Optional, Sequence, Tuple, Union
 
-from google.api_core import grpc_helpers  # type: ignore
-from google.api_core import operations_v1  # type: ignore
-from google.api_core import gapic_v1  # type: ignore
+from google.api_core import grpc_helpers
+from google.api_core import operations_v1
+from google.api_core import gapic_v1
 import google.auth  # type: ignore
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
@@ -53,7 +53,7 @@ class AutoMlGrpcTransport(AutoMlTransport):
     Currently the only supported ``location_id`` is "us-central1".
 
     On any input that is documented to expect a string parameter in
-    snake_case or kebab-case, either of those cases is accepted.
+    snake_case or dash-case, either of those cases is accepted.
 
     This class defines the same methods as the primary client, so the
     primary client can load the underlying transport implementation
@@ -132,7 +132,7 @@ class AutoMlGrpcTransport(AutoMlTransport):
         self._grpc_channel = None
         self._ssl_channel_credentials = ssl_channel_credentials
         self._stubs: Dict[str, Callable] = {}
-        self._operations_client = None
+        self._operations_client: Optional[operations_v1.OperationsClient] = None
 
         if api_mtls_endpoint:
             warnings.warn("api_mtls_endpoint is deprecated", DeprecationWarning)
@@ -626,7 +626,6 @@ class AutoMlGrpcTransport(AutoMlTransport):
         Deploys a model. If a model is already deployed, deploying it
         with the same parameters has no effect. Deploying with different
         parametrs (as e.g. changing
-
         [node_number][google.cloud.automl.v1p1beta.ImageObjectDetectionModelDeploymentMetadata.node_number])
         will reset the deployment state without pausing the model's
         availability.
