@@ -19,13 +19,18 @@ import re
 from typing import Dict, Sequence, Tuple, Type, Union
 import pkg_resources
 
-import google.api_core.client_options as ClientOptions  # type: ignore
-from google.api_core import exceptions as core_exceptions  # type: ignore
-from google.api_core import gapic_v1  # type: ignore
-from google.api_core import retry as retries  # type: ignore
+from google.api_core.client_options import ClientOptions
+from google.api_core import exceptions as core_exceptions
+from google.api_core import gapic_v1
+from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+try:
+    OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
+except AttributeError:  # pragma: NO COVER
+    OptionalRetry = Union[retries.Retry, object]  # type: ignore
+
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
 from google.cloud.automl_v1.types import annotation_payload
@@ -42,7 +47,7 @@ class PredictionServiceAsyncClient:
     """AutoML Prediction API.
 
     On any input that is documented to expect a string parameter in
-    snake_case or kebab-case, either of those cases is accepted.
+    snake_case or dash-case, either of those cases is accepted.
     """
 
     _client: PredictionServiceClient
@@ -172,12 +177,12 @@ class PredictionServiceAsyncClient:
 
     async def predict(
         self,
-        request: prediction_service.PredictRequest = None,
+        request: Union[prediction_service.PredictRequest, dict] = None,
         *,
         name: str = None,
         payload: data_items.ExamplePayload = None,
         params: Sequence[prediction_service.PredictRequest.ParamsEntry] = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> prediction_service.PredictResponse:
@@ -220,7 +225,7 @@ class PredictionServiceAsyncClient:
            up to 5MB. Not available for FORECASTING ``prediction_type``.
 
         Args:
-            request (:class:`google.cloud.automl_v1.types.PredictRequest`):
+            request (Union[google.cloud.automl_v1.types.PredictRequest, dict]):
                 The request object. Request message for
                 [PredictionService.Predict][google.cloud.automl.v1.PredictionService.Predict].
             name (:class:`str`):
@@ -265,7 +270,6 @@ class PredictionServiceAsyncClient:
                 AutoML Tables
 
                 ``feature_importance`` : (boolean) Whether
-
                 [feature_importance][google.cloud.automl.v1.TablesModelColumnInfo.feature_importance]
                 is populated in the returned list of
                 [TablesAnnotation][google.cloud.automl.v1.TablesAnnotation]
@@ -330,13 +334,13 @@ class PredictionServiceAsyncClient:
 
     async def batch_predict(
         self,
-        request: prediction_service.BatchPredictRequest = None,
+        request: Union[prediction_service.BatchPredictRequest, dict] = None,
         *,
         name: str = None,
         input_config: io.BatchPredictInputConfig = None,
         output_config: io.BatchPredictOutputConfig = None,
         params: Sequence[prediction_service.BatchPredictRequest.ParamsEntry] = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
@@ -362,7 +366,7 @@ class PredictionServiceAsyncClient:
         -  AutoML Tables
 
         Args:
-            request (:class:`google.cloud.automl_v1.types.BatchPredictRequest`):
+            request (Union[google.cloud.automl_v1.types.BatchPredictRequest, dict]):
                 The request object. Request message for
                 [PredictionService.BatchPredict][google.cloud.automl.v1.PredictionService.BatchPredict].
             name (:class:`str`):
