@@ -16,12 +16,11 @@
 import warnings
 from typing import Awaitable, Callable, Dict, Optional, Sequence, Tuple, Union
 
-from google.api_core import gapic_v1  # type: ignore
-from google.api_core import grpc_helpers_async  # type: ignore
-from google.api_core import operations_v1  # type: ignore
+from google.api_core import gapic_v1
+from google.api_core import grpc_helpers_async
+from google.api_core import operations_v1
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-import packaging.version
 
 import grpc  # type: ignore
 from grpc.experimental import aio  # type: ignore
@@ -38,7 +37,7 @@ class PredictionServiceGrpcAsyncIOTransport(PredictionServiceTransport):
     AutoML Prediction API.
 
     On any input that is documented to expect a string parameter in
-    snake_case or kebab-case, either of those cases is accepted.
+    snake_case or dash-case, either of those cases is accepted.
 
     This class defines the same methods as the primary client, so the
     primary client can load the underlying transport implementation
@@ -162,7 +161,7 @@ class PredictionServiceGrpcAsyncIOTransport(PredictionServiceTransport):
         self._grpc_channel = None
         self._ssl_channel_credentials = ssl_channel_credentials
         self._stubs: Dict[str, Callable] = {}
-        self._operations_client = None
+        self._operations_client: Optional[operations_v1.OperationsAsyncClient] = None
 
         if api_mtls_endpoint:
             warnings.warn("api_mtls_endpoint is deprecated", DeprecationWarning)
