@@ -36,11 +36,16 @@ class Image(proto.Message):
     r"""A representation of an image.
     Only images up to 30MB in size are supported.
 
+
+    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
     Attributes:
         image_bytes (bytes):
             Image content represented as a stream of bytes. Note: As
             with all ``bytes`` fields, protobuffers use a pure binary
             representation, whereas JSON representations use base64.
+
+            This field is a member of `oneof`_ ``data``.
         thumbnail_uri (str):
             Output only. HTTP URI to the thumbnail image.
     """
@@ -134,7 +139,6 @@ class Document(proto.Message):
                 The position of the
                 [text_segment][google.cloud.automl.v1.Document.Layout.text_segment]
                 in the page. Contains exactly 4
-
                 [normalized_vertices][google.cloud.automl.v1p1beta.BoundingPoly.normalized_vertices]
                 and they are connected by edges in the order provided, which
                 will represent a rectangle parallel to the frame. The
@@ -185,13 +189,26 @@ class Document(proto.Message):
 class ExamplePayload(proto.Message):
     r"""Example data used for training or prediction.
 
+    This message has `oneof`_ fields (mutually exclusive fields).
+    For each oneof, at most one member field can be set at the same time.
+    Setting any member of the oneof automatically clears all other
+    members.
+
+    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
     Attributes:
         image (google.cloud.automl_v1.types.Image):
             Example image.
+
+            This field is a member of `oneof`_ ``payload``.
         text_snippet (google.cloud.automl_v1.types.TextSnippet):
             Example text.
+
+            This field is a member of `oneof`_ ``payload``.
         document (google.cloud.automl_v1.types.Document):
             Example document.
+
+            This field is a member of `oneof`_ ``payload``.
     """
 
     image = proto.Field(proto.MESSAGE, number=1, oneof="payload", message="Image",)
