@@ -31,25 +31,41 @@ __protobuf__ = proto.module(
 class ModelEvaluation(proto.Message):
     r"""Evaluation results of a model.
 
+    This message has `oneof`_ fields (mutually exclusive fields).
+    For each oneof, at most one member field can be set at the same time.
+    Setting any member of the oneof automatically clears all other
+    members.
+
+    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
     Attributes:
         classification_evaluation_metrics (google.cloud.automl_v1.types.ClassificationEvaluationMetrics):
             Model evaluation metrics for image, text,
             video and tables classification.
             Tables problem is considered a classification
             when the target column is CATEGORY DataType.
+
+            This field is a member of `oneof`_ ``metrics``.
         translation_evaluation_metrics (google.cloud.automl_v1.types.TranslationEvaluationMetrics):
             Model evaluation metrics for translation.
+
+            This field is a member of `oneof`_ ``metrics``.
         image_object_detection_evaluation_metrics (google.cloud.automl_v1.types.ImageObjectDetectionEvaluationMetrics):
             Model evaluation metrics for image object
             detection.
+
+            This field is a member of `oneof`_ ``metrics``.
         text_sentiment_evaluation_metrics (google.cloud.automl_v1.types.TextSentimentEvaluationMetrics):
             Evaluation metrics for text sentiment models.
+
+            This field is a member of `oneof`_ ``metrics``.
         text_extraction_evaluation_metrics (google.cloud.automl_v1.types.TextExtractionEvaluationMetrics):
             Evaluation metrics for text extraction
             models.
+
+            This field is a member of `oneof`_ ``metrics``.
         name (str):
             Output only. Resource name of the model evaluation. Format:
-
             ``projects/{project_id}/locations/{location_id}/models/{model_id}/modelEvaluations/{model_evaluation_id}``
         annotation_spec_id (str):
             Output only. The ID of the annotation spec that the model
@@ -57,7 +73,6 @@ class ModelEvaluation(proto.Message):
             model evaluation. For Tables annotation specs in the dataset
             do not exist and this ID is always not set, but for
             CLASSIFICATION
-
             [prediction_type-s][google.cloud.automl.v1.TablesModelMetadata.prediction_type]
             the
             [display_name][google.cloud.automl.v1.ModelEvaluation.display_name]
@@ -70,7 +85,6 @@ class ModelEvaluation(proto.Message):
             trained from the same dataset, the values may differ, since
             display names could had been changed between the two model's
             trainings. For Tables CLASSIFICATION
-
             [prediction_type-s][google.cloud.automl.v1.TablesModelMetadata.prediction_type]
             distinct values of the target column at the moment of the
             model evaluation are populated here. The display_name is
@@ -87,7 +101,6 @@ class ModelEvaluation(proto.Message):
             examples used for evaluation. Otherwise, this is the count
             of examples that according to the ground truth were
             annotated by the
-
             [annotation_spec_id][google.cloud.automl.v1.ModelEvaluation.annotation_spec_id].
     """
 
