@@ -15,7 +15,6 @@
 #
 import os
 import mock
-import packaging.version
 
 import grpc
 from grpc.experimental import aio
@@ -40,9 +39,6 @@ from google.cloud.automl_v1.services.prediction_service import (
 )
 from google.cloud.automl_v1.services.prediction_service import PredictionServiceClient
 from google.cloud.automl_v1.services.prediction_service import transports
-from google.cloud.automl_v1.services.prediction_service.transports.base import (
-    _GOOGLE_AUTH_VERSION,
-)
 from google.cloud.automl_v1.types import annotation_payload
 from google.cloud.automl_v1.types import data_items
 from google.cloud.automl_v1.types import geometry
@@ -55,20 +51,6 @@ from google.oauth2 import service_account
 import google.auth
 
 
-# TODO(busunkim): Once google-auth >= 1.25.0 is required transitively
-# through google-api-core:
-# - Delete the auth "less than" test cases
-# - Delete these pytest markers (Make the "greater than or equal to" tests the default).
-requires_google_auth_lt_1_25_0 = pytest.mark.skipif(
-    packaging.version.parse(_GOOGLE_AUTH_VERSION) >= packaging.version.parse("1.25.0"),
-    reason="This test requires google-auth < 1.25.0",
-)
-requires_google_auth_gte_1_25_0 = pytest.mark.skipif(
-    packaging.version.parse(_GOOGLE_AUTH_VERSION) < packaging.version.parse("1.25.0"),
-    reason="This test requires google-auth >= 1.25.0",
-)
-
-
 def client_cert_source_callback():
     return b"cert bytes", b"key bytes"
 
@@ -226,7 +208,7 @@ def test_prediction_service_client_client_options(
     options = client_options.ClientOptions(api_endpoint="squid.clam.whelk")
     with mock.patch.object(transport_class, "__init__") as patched:
         patched.return_value = None
-        client = client_class(client_options=options)
+        client = client_class(transport=transport_name, client_options=options)
         patched.assert_called_once_with(
             credentials=None,
             credentials_file=None,
@@ -243,7 +225,7 @@ def test_prediction_service_client_client_options(
     with mock.patch.dict(os.environ, {"GOOGLE_API_USE_MTLS_ENDPOINT": "never"}):
         with mock.patch.object(transport_class, "__init__") as patched:
             patched.return_value = None
-            client = client_class()
+            client = client_class(transport=transport_name)
             patched.assert_called_once_with(
                 credentials=None,
                 credentials_file=None,
@@ -260,7 +242,7 @@ def test_prediction_service_client_client_options(
     with mock.patch.dict(os.environ, {"GOOGLE_API_USE_MTLS_ENDPOINT": "always"}):
         with mock.patch.object(transport_class, "__init__") as patched:
             patched.return_value = None
-            client = client_class()
+            client = client_class(transport=transport_name)
             patched.assert_called_once_with(
                 credentials=None,
                 credentials_file=None,
@@ -276,20 +258,20 @@ def test_prediction_service_client_client_options(
     # unsupported value.
     with mock.patch.dict(os.environ, {"GOOGLE_API_USE_MTLS_ENDPOINT": "Unsupported"}):
         with pytest.raises(MutualTLSChannelError):
-            client = client_class()
+            client = client_class(transport=transport_name)
 
     # Check the case GOOGLE_API_USE_CLIENT_CERTIFICATE has unsupported value.
     with mock.patch.dict(
         os.environ, {"GOOGLE_API_USE_CLIENT_CERTIFICATE": "Unsupported"}
     ):
         with pytest.raises(ValueError):
-            client = client_class()
+            client = client_class(transport=transport_name)
 
     # Check the case quota_project_id is provided
     options = client_options.ClientOptions(quota_project_id="octopus")
     with mock.patch.object(transport_class, "__init__") as patched:
         patched.return_value = None
-        client = client_class(client_options=options)
+        client = client_class(client_options=options, transport=transport_name)
         patched.assert_called_once_with(
             credentials=None,
             credentials_file=None,
@@ -358,7 +340,7 @@ def test_prediction_service_client_mtls_env_auto(
         )
         with mock.patch.object(transport_class, "__init__") as patched:
             patched.return_value = None
-            client = client_class(client_options=options)
+            client = client_class(client_options=options, transport=transport_name)
 
             if use_client_cert_env == "false":
                 expected_client_cert_source = None
@@ -400,7 +382,7 @@ def test_prediction_service_client_mtls_env_auto(
                         expected_client_cert_source = client_cert_source_callback
 
                     patched.return_value = None
-                    client = client_class()
+                    client = client_class(transport=transport_name)
                     patched.assert_called_once_with(
                         credentials=None,
                         credentials_file=None,
@@ -422,7 +404,7 @@ def test_prediction_service_client_mtls_env_auto(
                 return_value=False,
             ):
                 patched.return_value = None
-                client = client_class()
+                client = client_class(transport=transport_name)
                 patched.assert_called_once_with(
                     credentials=None,
                     credentials_file=None,
@@ -453,7 +435,7 @@ def test_prediction_service_client_client_options_scopes(
     options = client_options.ClientOptions(scopes=["1", "2"],)
     with mock.patch.object(transport_class, "__init__") as patched:
         patched.return_value = None
-        client = client_class(client_options=options)
+        client = client_class(client_options=options, transport=transport_name)
         patched.assert_called_once_with(
             credentials=None,
             credentials_file=None,
@@ -484,7 +466,7 @@ def test_prediction_service_client_client_options_credentials_file(
     options = client_options.ClientOptions(credentials_file="credentials.json")
     with mock.patch.object(transport_class, "__init__") as patched:
         patched.return_value = None
-        client = client_class(client_options=options)
+        client = client_class(client_options=options, transport=transport_name)
         patched.assert_called_once_with(
             credentials=None,
             credentials_file="credentials.json",
@@ -517,9 +499,8 @@ def test_prediction_service_client_client_options_from_dict():
         )
 
 
-def test_predict(
-    transport: str = "grpc", request_type=prediction_service.PredictRequest
-):
+@pytest.mark.parametrize("request_type", [prediction_service.PredictRequest, dict,])
+def test_predict(request_type, transport: str = "grpc"):
     client = PredictionServiceClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -543,10 +524,6 @@ def test_predict(
     assert isinstance(response, prediction_service.PredictResponse)
 
 
-def test_predict_from_dict():
-    test_predict(request_type=dict)
-
-
 def test_predict_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
@@ -670,11 +647,17 @@ def test_predict_flattened():
         # request object values.
         assert len(call.mock_calls) == 1
         _, args, _ = call.mock_calls[0]
-        assert args[0].name == "name_value"
-        assert args[0].payload == data_items.ExamplePayload(
+        arg = args[0].name
+        mock_val = "name_value"
+        assert arg == mock_val
+        arg = args[0].payload
+        mock_val = data_items.ExamplePayload(
             image=data_items.Image(image_bytes=b"image_bytes_blob")
         )
-        assert args[0].params == {"key_value": "value_value"}
+        assert arg == mock_val
+        arg = args[0].params
+        mock_val = {"key_value": "value_value"}
+        assert arg == mock_val
 
 
 def test_predict_flattened_error():
@@ -721,11 +704,17 @@ async def test_predict_flattened_async():
         # request object values.
         assert len(call.mock_calls)
         _, args, _ = call.mock_calls[0]
-        assert args[0].name == "name_value"
-        assert args[0].payload == data_items.ExamplePayload(
+        arg = args[0].name
+        mock_val = "name_value"
+        assert arg == mock_val
+        arg = args[0].payload
+        mock_val = data_items.ExamplePayload(
             image=data_items.Image(image_bytes=b"image_bytes_blob")
         )
-        assert args[0].params == {"key_value": "value_value"}
+        assert arg == mock_val
+        arg = args[0].params
+        mock_val = {"key_value": "value_value"}
+        assert arg == mock_val
 
 
 @pytest.mark.asyncio
@@ -747,9 +736,10 @@ async def test_predict_flattened_error_async():
         )
 
 
-def test_batch_predict(
-    transport: str = "grpc", request_type=prediction_service.BatchPredictRequest
-):
+@pytest.mark.parametrize(
+    "request_type", [prediction_service.BatchPredictRequest, dict,]
+)
+def test_batch_predict(request_type, transport: str = "grpc"):
     client = PredictionServiceClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -773,10 +763,6 @@ def test_batch_predict(
     assert isinstance(response, future.Future)
 
 
-def test_batch_predict_from_dict():
-    test_batch_predict(request_type=dict)
-
-
 def test_batch_predict_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
@@ -905,16 +891,24 @@ def test_batch_predict_flattened():
         # request object values.
         assert len(call.mock_calls) == 1
         _, args, _ = call.mock_calls[0]
-        assert args[0].name == "name_value"
-        assert args[0].input_config == io.BatchPredictInputConfig(
+        arg = args[0].name
+        mock_val = "name_value"
+        assert arg == mock_val
+        arg = args[0].input_config
+        mock_val = io.BatchPredictInputConfig(
             gcs_source=io.GcsSource(input_uris=["input_uris_value"])
         )
-        assert args[0].output_config == io.BatchPredictOutputConfig(
+        assert arg == mock_val
+        arg = args[0].output_config
+        mock_val = io.BatchPredictOutputConfig(
             gcs_destination=io.GcsDestination(
                 output_uri_prefix="output_uri_prefix_value"
             )
         )
-        assert args[0].params == {"key_value": "value_value"}
+        assert arg == mock_val
+        arg = args[0].params
+        mock_val = {"key_value": "value_value"}
+        assert arg == mock_val
 
 
 def test_batch_predict_flattened_error():
@@ -971,16 +965,24 @@ async def test_batch_predict_flattened_async():
         # request object values.
         assert len(call.mock_calls)
         _, args, _ = call.mock_calls[0]
-        assert args[0].name == "name_value"
-        assert args[0].input_config == io.BatchPredictInputConfig(
+        arg = args[0].name
+        mock_val = "name_value"
+        assert arg == mock_val
+        arg = args[0].input_config
+        mock_val = io.BatchPredictInputConfig(
             gcs_source=io.GcsSource(input_uris=["input_uris_value"])
         )
-        assert args[0].output_config == io.BatchPredictOutputConfig(
+        assert arg == mock_val
+        arg = args[0].output_config
+        mock_val = io.BatchPredictOutputConfig(
             gcs_destination=io.GcsDestination(
                 output_uri_prefix="output_uri_prefix_value"
             )
         )
-        assert args[0].params == {"key_value": "value_value"}
+        assert arg == mock_val
+        arg = args[0].params
+        mock_val = {"key_value": "value_value"}
+        assert arg == mock_val
 
 
 @pytest.mark.asyncio
@@ -1120,7 +1122,6 @@ def test_prediction_service_base_transport():
         transport.operations_client
 
 
-@requires_google_auth_gte_1_25_0
 def test_prediction_service_base_transport_with_credentials_file():
     # Instantiate the base transport with a credentials file
     with mock.patch.object(
@@ -1141,26 +1142,6 @@ def test_prediction_service_base_transport_with_credentials_file():
         )
 
 
-@requires_google_auth_lt_1_25_0
-def test_prediction_service_base_transport_with_credentials_file_old_google_auth():
-    # Instantiate the base transport with a credentials file
-    with mock.patch.object(
-        google.auth, "load_credentials_from_file", autospec=True
-    ) as load_creds, mock.patch(
-        "google.cloud.automl_v1.services.prediction_service.transports.PredictionServiceTransport._prep_wrapped_messages"
-    ) as Transport:
-        Transport.return_value = None
-        load_creds.return_value = (ga_credentials.AnonymousCredentials(), None)
-        transport = transports.PredictionServiceTransport(
-            credentials_file="credentials.json", quota_project_id="octopus",
-        )
-        load_creds.assert_called_once_with(
-            "credentials.json",
-            scopes=("https://www.googleapis.com/auth/cloud-platform",),
-            quota_project_id="octopus",
-        )
-
-
 def test_prediction_service_base_transport_with_adc():
     # Test the default credentials are used if credentials and credentials_file are None.
     with mock.patch.object(google.auth, "default", autospec=True) as adc, mock.patch(
@@ -1172,7 +1153,6 @@ def test_prediction_service_base_transport_with_adc():
         adc.assert_called_once()
 
 
-@requires_google_auth_gte_1_25_0
 def test_prediction_service_auth_adc():
     # If no credentials are provided, we should use ADC credentials.
     with mock.patch.object(google.auth, "default", autospec=True) as adc:
@@ -1185,18 +1165,6 @@ def test_prediction_service_auth_adc():
         )
 
 
-@requires_google_auth_lt_1_25_0
-def test_prediction_service_auth_adc_old_google_auth():
-    # If no credentials are provided, we should use ADC credentials.
-    with mock.patch.object(google.auth, "default", autospec=True) as adc:
-        adc.return_value = (ga_credentials.AnonymousCredentials(), None)
-        PredictionServiceClient()
-        adc.assert_called_once_with(
-            scopes=("https://www.googleapis.com/auth/cloud-platform",),
-            quota_project_id=None,
-        )
-
-
 @pytest.mark.parametrize(
     "transport_class",
     [
@@ -1204,7 +1172,6 @@ def test_prediction_service_auth_adc_old_google_auth():
         transports.PredictionServiceGrpcAsyncIOTransport,
     ],
 )
-@requires_google_auth_gte_1_25_0
 def test_prediction_service_transport_auth_adc(transport_class):
     # If credentials and host are not provided, the transport class should use
     # ADC credentials.
@@ -1218,26 +1185,6 @@ def test_prediction_service_transport_auth_adc(transport_class):
         )
 
 
-@pytest.mark.parametrize(
-    "transport_class",
-    [
-        transports.PredictionServiceGrpcTransport,
-        transports.PredictionServiceGrpcAsyncIOTransport,
-    ],
-)
-@requires_google_auth_lt_1_25_0
-def test_prediction_service_transport_auth_adc_old_google_auth(transport_class):
-    # If credentials and host are not provided, the transport class should use
-    # ADC credentials.
-    with mock.patch.object(google.auth, "default", autospec=True) as adc:
-        adc.return_value = (ga_credentials.AnonymousCredentials(), None)
-        transport_class(quota_project_id="octopus")
-        adc.assert_called_once_with(
-            scopes=("https://www.googleapis.com/auth/cloud-platform",),
-            quota_project_id="octopus",
-        )
-
-
 @pytest.mark.parametrize(
     "transport_class,grpc_helpers",
     [
@@ -1608,7 +1555,7 @@ def test_parse_common_location_path():
     assert expected == actual
 
 
-def test_client_withDEFAULT_CLIENT_INFO():
+def test_client_with_default_client_info():
     client_info = gapic_v1.client_info.ClientInfo()
 
     with mock.patch.object(
